@@ -37,6 +37,11 @@ public:
 
   virtual LayoutItem* clone() const;
 
+  bool operator==(const LayoutItem_Field& src) const;
+
+  virtual void set_name(const Glib::ustring& name);
+  virtual Glib::ustring get_name() const; //For use with our std::find_if() predicate.
+
   //virtual Glib::ustring get_table_name() const;
   //virtual void set_table_name(const Glib::ustring& table_name);
 
