@@ -110,6 +110,9 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
   m_FlowTable.signal_field_edited().connect( sigc::mem_fun(*this,  &Box_Data_Details::on_flowtable_field_edited) );
   show_all();
 
+  m_FlowTable.signal_related_record_changed().connect( sigc::mem_fun(*this, &Box_Data_Details::on_flowtable_related_record_changed) );
+
+
   m_FlowTable.signal_layout_changed().connect( sigc::mem_fun(*this, &Box_Data_Details::on_flowtable_layout_changed) );
 
   m_ignore_signals = false;
@@ -117,6 +120,7 @@ Box_Data_Details::Box_Data_Details(bool bWithNavButtons /* = true */)
 
 Box_Data_Details::~Box_Data_Details()
 {
+  remove_view(&m_FlowTable);
 }
 
 Gnome::Gda::Value Box_Data_Details::get_primary_key_value() const
@@ -157,6 +161,8 @@ void Box_Data_Details::fill_from_database_layout()
 
     //This map of layout groups will also contain the field information from the database:
     Document_Glom::type_mapLayoutGroupSequence layout_groups = get_data_layout_groups("details");
+
+
     for(Document_Glom::type_mapLayoutGroupSequence::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
     {
       m_FlowTable.add_layout_group(iter->second);
@@ -196,7 +202,6 @@ void Box_Data_Details::fill_from_database()
       {
         //Add extra possibly-non-visible columns that we need:
         LayoutItem_Field layout_item;
-        layout_item.set_name(m_field_primary_key.get_name());
         layout_item.m_field = m_field_primary_key;
         fieldsToGet.push_back(layout_item);
 
@@ -436,6 +441,35 @@ void Box_Data_Details::on_related_user_requested_details(Gnome::Gda::Value key_v
 }
 */
 
+void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustring& relationship_name)
+{
+ //TODO: Get (recursively) the list of fields to recalcualte, sort them in order of dependency, then calculate them all.
+
+  const Gnome::Gda::Value primary_key_value = get_primary_key_value();
+
+  for(type_vecLayoutFields::iterator iter = m_Fields.begin(); iter != m_Fields.end(); ++iter)
+  {
+    const LayoutItem_Field& field = *iter;
+
+    //Is this field triggered by this relationship?
+    const Field::type_list_strings triggered_by = field.m_field.get_calculation_relationships();
+    Field::type_list_strings::const_iterator iterFind = std::find(triggered_by.begin(), triggered_by.end(), relationship_name);
+    if(iterFind != triggered_by.end()) //If it was found
+    {
+       //recalculate:
+       const type_map_fields field_values = get_record_field_values(primary_key_value);
+       Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field.m_field.get_glom_type(), iter->m_field.get_calculation(), field_values,
+          get_document(), m_strTableName);
+
+      //show it:
+      set_entered_field_data(field, value);
+
+      //Add it to the database (even if it is not shown in the view)
+      set_field_value_in_database(field, value, m_field_primary_key, primary_key_value);
+    }
+  }
+}
+
 void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue */, Glib::ustring /* strFromKeyName */)
 {
   //Prevent deletion of Related boxes.
@@ -460,6 +494,8 @@ void Box_Data_Details::on_related_record_added(Gnome::Gda::Value /* strKeyValue
   }
   */
 
+  
+
   //Restore value:
   m_bDoNotRefreshRelated = bDoNotRefreshRelated;
 }
@@ -513,6 +549,11 @@ void Box_Data_Details::on_flowtable_layout_changed()
   fill_from_database();
 }
 
+void Box_Data_Details::on_flowtable_related_record_changed(const Glib::ustring& relationship_name)
+{
+  recalculate_fields_for_related_records(relationship_name);
+}
+
 void Box_Data_Details::on_flowtable_field_edited(const LayoutItem_Field& layout_field, const Gnome::Gda::Value& field_value)
 {
   if(m_ignore_signals)
@@ -573,15 +614,19 @@ void Box_Data_Details::on_flowtable_field_edited(const LayoutItem_Field& layout_
       }
     }
 
-    const Field& field = layout_field.m_field;
+    //const Field& field = layout_field.m_field;
+
+    //Set the value in all instances of this field in the layout (The field might be on the layout more than once):
+    m_FlowTable.set_field_value(layout_field, field_value);
 
     //Update the field in the record (the record with this primary key):
     try
     {
-      Glib::ustring strQuery = "UPDATE " + table_name;
-      strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
-      strQuery += " WHERE " + table_name + "." + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
-      bool bTest = Query_execute(strQuery);
+      bool bTest = set_field_value_in_database(layout_field, field_value, primary_key_field, primary_key_value);
+      //Glib::ustring strQuery = "UPDATE " + table_name;
+      //strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
+      //strQuery += " WHERE " + table_name + "." + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
+      //bool bTest = Query_execute(strQuery);
 
       if(!bTest)
       {
@@ -590,18 +635,6 @@ void Box_Data_Details::on_flowtable_field_edited(const LayoutItem_Field& layout_
       }
       else
       {
-        //Set the value in all instances of this field in the layout (The field might be on the layout more than once):
-        m_FlowTable.set_field_value(layout_field, field_value);
-
-        //Get-and-set values for lookup fields, if this field triggers those relationships:
-        do_lookups(layout_field, field_value, primary_key_field, primary_key_value);
-
-        //Recalculate calculated fields, if this field is used by them:
-        do_calculations(layout_field, primary_key_field, primary_key_value);
-
-        //Show new values for related fields:
-        refresh_related_fields(layout_field, field_value, primary_key_field, primary_key_value);
-
         //TODO: Display new values for related fields.
 
         //If this is a foreign key then refresh the related records:
@@ -668,7 +701,7 @@ void Box_Data_Details::on_flowtable_field_edited(const LayoutItem_Field& layout_
   } //if(get_primary_key_value().size())
 }
 
-void Box_Data_Details::refresh_related_fields(const LayoutItem_Field& field_changed, const Gnome::Gda::Value& /* field_value */, const Field& primary_key, const Gnome::Gda::Value& primary_key_value)
+void Box_Data_Details::refresh_related_fields(const Gtk::TreeModel::iterator& /* row */, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& /* field_value */, const Field& primary_key, const Gnome::Gda::Value& primary_key_value)
 {
   if(field_changed.get_has_relationship_name())
     return; //TODO: Handle these too.
@@ -710,7 +743,7 @@ void Box_Data_Details::refresh_related_fields(const LayoutItem_Field& field_chan
   }
 }
 
-void Box_Data_Details::do_lookups(const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value)
+void Box_Data_Details::do_lookups(const Gtk::TreeModel::iterator& /* row */, const LayoutItem_Field& field_changed, const Gnome::Gda::Value& field_value, const Field& primary_key, const Gnome::Gda::Value& primary_key_value)
 {
    if(field_changed.get_has_relationship_name())
     return; //TODO: Handle these too.
@@ -739,8 +772,6 @@ void Box_Data_Details::do_lookups(const LayoutItem_Field& field_changed, const G
 
        //Add it to the database (even if it is not shown in the view)
        set_field_value_in_database(layout_item, value, primary_key, primary_key_value);
-
-       //TODO: Handle lookups triggered by these fields (recursively)? TODO: Check for infinitely looping lookups.
      }
    }
 }
