@@ -95,6 +95,8 @@ void Box_Data_List::fill_from_database()
     m_AddDel.set_allow_add(table_privs.m_create);
     m_AddDel.set_allow_delete(table_privs.m_delete);
 
+    m_AddDel.set_where_clause(m_strWhereClause);
+
     if(table_privs.m_view)
     {
 /*
@@ -109,7 +111,6 @@ void Box_Data_List::fill_from_database()
 
       LayoutItem_Field layout_item;
       Field field_key = m_AddDel.get_key_field();
-      layout_item.set_name(field_key.get_name());
       layout_item.m_field = field_key;
       fieldsToGet.push_back(layout_item);
       //const int index_primary_key = fieldsToGet.size() - 1;
@@ -252,14 +253,17 @@ void Box_Data_List::on_adddel_user_requested_delete(const Gtk::TreeModel::iterat
     dialog.set_transient_for(*get_app_window());
     dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     dialog.add_button(Gtk::Stock::DELETE, Gtk::RESPONSE_OK);
-    
+
     int response = dialog.run();
     if(response == Gtk::RESPONSE_OK)
     {
-      record_delete( get_primary_key_value(rowStart) );
+      const Gnome::Gda::Value primary_key_value = get_primary_key_value(rowStart);
+      record_delete(primary_key_value);
 
       //Remove the row:
       m_AddDel.remove_item(rowStart);
+
+      on_record_deleted(primary_key_value);
     }
   }
 }
@@ -281,7 +285,6 @@ void Box_Data_List::on_adddel_user_added(const Gtk::TreeModel::iterator& row, gu
   {
     //This only works when the primary key is already stored: primary_key_value = get_primary_key_value(row);
     LayoutItem_Field layout_item;
-    layout_item.set_name(field_primary_key.get_name());
     layout_item.m_field = field_primary_key;
     primary_key_value = get_entered_field_data(layout_item);
   }
@@ -304,7 +307,6 @@ void Box_Data_List::on_adddel_user_added(const Gtk::TreeModel::iterator& row, gu
         if(fieldInfo.get_auto_increment())
         {
           LayoutItem_Field layout_item;
-          layout_item.set_name(field_primary_key.get_name());
           layout_item.m_field = field_primary_key;
           m_AddDel.set_value(row, layout_item, primary_key_value);
         }
@@ -415,18 +417,21 @@ void Box_Data_List::on_adddel_user_changed(const Gtk::TreeModel::iterator& row,
 
       //Update the field in the record (the record with this primary key):
       const Gnome::Gda::Value field_value = m_AddDel.get_value(row, layout_field);
-      const Field& field = layout_field.m_field;
-      const Glib::ustring strFieldName = layout_field.get_name();
+      //const Field& field = layout_field.m_field;
+      //const Glib::ustring strFieldName = layout_field.get_name();
 
-      Glib::ustring strQuery = "UPDATE " + table_name;
-      strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
-      strQuery += " WHERE " + table_name + "." + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
-      bool bTest = Query_execute(strQuery);
+      bool bTest = set_field_value_in_database(row, layout_field, field_value, primary_key_field, primary_key_value);
+
+      //Glib::ustring strQuery = "UPDATE " + table_name;
+      //strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
+      //strQuery += " WHERE " + table_name + "." + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
+      //bool bTest = Query_execute(strQuery);
       if(!bTest)
       {
         //Update failed.
         fill_from_database(); //Replace with correct values.
       }
+      /*
       else
       {
         //Get-and-set values for lookup fields, if this field triggers those relationships:
@@ -438,6 +443,7 @@ void Box_Data_List::on_adddel_user_changed(const Gtk::TreeModel::iterator& row,
         //Update related fields, if this field is used in the relationship:
         refresh_related_fields(row, layout_field, field_value, primary_key_field, primary_key_value);
       }
+      */
     }
     catch(const std::exception& ex)
     {
@@ -536,10 +542,11 @@ void Box_Data_List::do_lookups(const Gtk::TreeModel::iterator& row, const Layout
        m_AddDel.set_value(row, layout_Item, value);
 
        //Add it to the database (even if it is not shown in the view)
-       Glib::ustring strQuery = "UPDATE " + m_strTableName;
-       strQuery += " SET " + field_lookup.get_name() + " = " + field_lookup.sql(value);
-       strQuery += " WHERE " + primary_key.get_name() + " = " + primary_key.sql(primary_key_value);
-       Query_execute(strQuery);  //TODO: Handle errors
+       set_field_value_in_database(row, layout_Item, value, primary_key, primary_key_value); //Also does dependent lookups/recalcs.
+       //Glib::ustring strQuery = "UPDATE " + m_strTableName;
+       //strQuery += " SET " + field_lookup.get_name() + " = " + field_lookup.sql(value);
+       //strQuery += " WHERE " + primary_key.get_name() + " = " + primary_key.sql(primary_key_value);
+       //Query_execute(strQuery);  //TODO: Handle errors
 
        //TODO: Handle lookups triggered by these fields (recursively)? TODO: Check for infinitely looping lookups.
      }
@@ -668,7 +675,9 @@ void Box_Data_List::fill_column_titles()
     Field field_primary_key;
     bool test = get_field_primary_key_for_table(m_strTableName, field_primary_key);
     if(!test)
-      g_warning("Box_Data_List::fill_column_titles(): primary key not found.");
+    {
+      //g_warning("Box_Data_List::fill_column_titles(): primary key not found.");
+    }
     else
     {
       m_AddDel.set_key_field(field_primary_key);
@@ -681,7 +690,6 @@ void Box_Data_List::fill_column_titles()
       LayoutItem_Field layout_item;
       layout_item.set_hidden();
       Field field_key = m_AddDel.get_key_field();
-      layout_item.set_name(field_key.get_name());
       layout_item.m_field = field_key;
       m_Fields.push_back(layout_item);
 
@@ -691,12 +699,19 @@ void Box_Data_List::fill_column_titles()
         m_AddDel.add_column(*iter);
       }
 
+      m_AddDel.set_where_clause(m_strWhereClause);
+
       m_AddDel.set_columns_ready();
      }
   }
 
 }
 
+void Box_Data_List::on_record_deleted(const Gnome::Gda::Value& /* primary_key_value */)
+{
+   //Overridden by Box_Data_List_Related.
+}
+
 void Box_Data_List::on_record_added(const Gnome::Gda::Value& /* strPrimaryKey */)
 {
   //Overridden by Box_Data_List_Related.
