@@ -36,11 +36,12 @@ Box_DB_Table_Definition::Box_DB_Table_Definition(BaseObjectType* cobject, const
 
 void Box_DB_Table_Definition::init()
 {
-  m_strHint = _("Click [Edit] to edit the field definition in more detail.\nUse the Mode menu to see Data or perform a Find.");
+  //m_strHint = _("Click [Edit] to edit the field definition in more detail.\nUse the Mode menu to see Data or perform a Find.");
 
   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_field_definition_edit");
   if(refXml)
     refXml->get_widget_derived("window_field_definition_edit", m_pDialog);
+
   add_view(m_pDialog); //Give it access to the document.
 
   pack_start(m_AddDel);
@@ -78,6 +79,11 @@ void Box_DB_Table_Definition::init()
 
 Box_DB_Table_Definition::~Box_DB_Table_Definition()
 {
+  if(m_pDialog)
+  {
+    remove_view(m_pDialog);
+    delete m_pDialog;
+  }
 }
 
 void Box_DB_Table_Definition::fill_field_row(const Gtk::TreeModel::iterator& iter, const Field& field)
