@@ -21,13 +21,10 @@
 #ifndef NOTEBOOK_FIND_H
 #define NOTEBOOK_FIND_H
 
-#include "../notebook_glom.h"
+#include "../mode_data/notebook_data.h"
 #include "box_data_list_find.h"
 #include "box_data_details_find.h"
 
-/**
-  *@author Murray Cumming
-  */
 
 class Notebook_Find : public Notebook_Glom
 {
@@ -35,7 +32,7 @@ public:
   Notebook_Find();
   virtual ~Notebook_Find();
 
-  virtual void init_db_details(const Glib::ustring& strDatabaseName, const Glib::ustring& strTableName);
+  virtual void init_db_details(const Glib::ustring& strTableName);
 
   //Signals:
   //where_clause.
