@@ -150,25 +150,25 @@ EntryGlom::type_signal_user_requested_layout EntryGlom::signal_user_requested_la
   return m_signal_user_requested_layout;
 }
 
+EntryGlom::type_signal_user_requested_layout_properties EntryGlom::signal_user_requested_layout_properties()
+{
+  return m_signal_user_requested_layout_properties;
+}
+
 void EntryGlom::setup_menu()
 {
-  m_refActionGroup = Gtk::ActionGroup::create();
-
-  m_refActionGroup->add(Gtk::Action::create("ContextMenu", "Context Menu") );
-
-  m_refContextLayout =  Gtk::Action::create("ContextLayout", _("Choose Field"));
   m_refActionGroup->add(m_refContextLayout,
     sigc::mem_fun(*this, &EntryGlom::on_menupopup_activate_layout) );
 
-  m_refContextAddField =  Gtk::Action::create("ContextAddField", _("Add Field"));
+  m_refActionGroup->add(m_refContextLayoutProperties,
+    sigc::mem_fun(*this, &EntryGlom::on_menupopup_activate_layout_properties) );
+
   m_refActionGroup->add(m_refContextAddField,
     sigc::bind( sigc::mem_fun(*this, &EntryGlom::on_menupopup_add_item), TreeStore_Layout::TYPE_FIELD ) );
 
-  m_refContextAddRelatedRecords =  Gtk::Action::create("ContextAddRelatedRecords", _("Add Related Records"));
   m_refActionGroup->add(m_refContextAddRelatedRecords,
     sigc::bind( sigc::mem_fun(*this, &EntryGlom::on_menupopup_add_item), TreeStore_Layout::TYPE_PORTAL ) );
 
-  m_refContextAddGroup =  Gtk::Action::create("ContextAddGroup", _("Add Group"));
   m_refActionGroup->add(m_refContextAddGroup,
     sigc::bind( sigc::mem_fun(*this, &EntryGlom::on_menupopup_add_item), TreeStore_Layout::TYPE_GROUP ) );
 
@@ -177,6 +177,7 @@ void EntryGlom::setup_menu()
   if(pApp)
   {
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
+    pApp->add_developer_action(m_refContextLayoutProperties); //So that it can be disabled when not in developer mode.
     pApp->add_developer_action(m_refContextAddField);
     pApp->add_developer_action(m_refContextAddRelatedRecords);
     pApp->add_developer_action(m_refContextAddGroup);
@@ -196,6 +197,7 @@ void EntryGlom::setup_menu()
         "<ui>"
         "  <popup name='ContextMenu'>"
         "    <menuitem action='ContextLayout'/>"
+        "    <menuitem action='ContextLayoutProperties'/>"
         "    <menuitem action='ContextAddField'/>"
         "    <menuitem action='ContextAddRelatedRecords'/>"
         "    <menuitem action='ContextAddGroup'/>"
@@ -265,6 +267,14 @@ void EntryGlom::on_menupopup_activate_layout()
   signal_user_requested_layout().emit();
 }
 
+void EntryGlom::on_menupopup_activate_layout_properties()
+{
+  //finish_editing();
+
+  //Ask the parent widget to show the layout dialog:
+  signal_user_requested_layout_properties().emit();
+}
+
 App_Glom* EntryGlom::get_application()
 {
   Gtk::Container* pWindow = get_toplevel();
