@@ -99,6 +99,7 @@ void FlowTableWithFields::add_layout_item_at_position(const LayoutItem& item, co
             Box_Data_List_Related* portal_box = Gtk::manage(new Box_Data_List_Related);
 
             portal_box->init_db_details(relationship);
+
             portal_box->set_layout_item(portal->clone(), relationship.get_to_table());
             portal_box->show();
             add(*portal_box, true /* expand */);
@@ -106,6 +107,9 @@ void FlowTableWithFields::add_layout_item_at_position(const LayoutItem& item, co
             m_portals.push_back(portal_box);
             add_layoutwidgetbase(portal_box, add_before);
 
+            //Connect signals:
+            portal_box->signal_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_record_changed) );
+
             add_view(portal_box);
           }
         }
@@ -172,6 +176,7 @@ void FlowTableWithFields::add_layout_group_at_position(const LayoutGroup& group,
 
     //Connect signal:
     flow_table->signal_field_edited().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_entry_edited) );
+    flow_table->signal_related_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_related_record_changed) );
   }
 }
 
@@ -308,6 +313,7 @@ void FlowTableWithFields::set_field_value(const LayoutItem_Field& field, const G
     Box_Data_List_Related* portal = dynamic_cast<Box_Data_List_Related*>(*iter);
     if(portal)
     {
+      //g_warning("FlowTableWithFields::set_field_value: foreign_key_value=%s", value.to_string().c_str());
       portal->refresh_db_details(value /* foreign key value */, Gnome::Gda::Value() /* TODO */);
     }
   }
@@ -472,7 +478,7 @@ void FlowTableWithFields::remove_all()
       delete pSub;
     }
   }
-  
+ 
   m_sub_flow_tables.clear();
 
 
@@ -495,6 +501,12 @@ FlowTableWithFields::type_signal_field_edited FlowTableWithFields::signal_field_
   return m_signal_field_edited;
 }
 
+FlowTableWithFields::type_signal_related_record_changed FlowTableWithFields::signal_related_record_changed()
+{
+  return m_signal_related_record_changed;
+}
+
+
 void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, LayoutItem_Field field)
 {
   m_signal_field_edited.emit(field, value);
@@ -666,4 +678,15 @@ void FlowTableWithFields::on_datawidget_layout_item_added(TreeStore_Layout::enum
   signal_layout_changed().emit(); //This should result in a complete re-layout.
 }
 
+void FlowTableWithFields::on_portal_record_changed(const Glib::ustring& relationship_name)
+{
+  signal_related_record_changed().emit(relationship_name);
+}
+
+void FlowTableWithFields::on_flowtable_related_record_changed(const Glib::ustring& relationship_name)
+{
+  //Forward it to the parent:
+  signal_related_record_changed().emit(relationship_name);
+}
+
 
