@@ -19,10 +19,21 @@
  */
 
 #include "layoutwidgetbase.h"
+#include <glibmm/i18n.h>
 
 LayoutWidgetBase::LayoutWidgetBase()
-: m_pLayoutItem(0)
+: m_pLayoutItem(0),
+  m_pMenuPopup(0)
 {
+  m_refActionGroup = Gtk::ActionGroup::create();
+
+  m_refActionGroup->add(Gtk::Action::create("ContextMenu", "Context Menu") );
+  m_refContextLayout =  Gtk::Action::create("ContextLayout", _("Choose Field"));
+  m_refContextLayoutProperties =  Gtk::Action::create("ContextLayoutProperties", _("Field Layout Properties"));
+  m_refContextAddField =  Gtk::Action::create("ContextAddField", _("Add Field"));
+  m_refContextAddRelatedRecords =  Gtk::Action::create("ContextAddRelatedRecords", _("Add Related Records"));
+  m_refContextAddGroup =  Gtk::Action::create("ContextAddGroup", _("Add Group"));
+
 }
 
 LayoutWidgetBase::~LayoutWidgetBase()
@@ -57,3 +68,8 @@ LayoutWidgetBase::type_signal_layout_changed LayoutWidgetBase::signal_layout_cha
 {
   return m_signal_layout_changed;
 }
+
+LayoutWidgetBase::type_signal_layout_item_added LayoutWidgetBase::signal_layout_item_added()
+{
+  return m_signal_layout_item_added;
+}
